Class: Gaskit::Generators::ServiceGenerator
- Inherits:
-
OperationGenerator
- Object
- Rails::Generators::NamedBase
- OperationGenerator
- Gaskit::Generators::ServiceGenerator
- Defined in:
- lib/generators/gaskit/operation/service_generator.rb
Overview
A Rails generator for creating new service classes that inherit from Gaskit::Service.
This generator supports namespaced services and places them under app/services.
Constant Summary
Constants inherited from OperationGenerator
OperationGenerator::SUPPORTED_TYPES
Instance Method Summary collapse
-
#initialize(*args) ⇒ ServiceGenerator
constructor
A new instance of ServiceGenerator.
Methods inherited from OperationGenerator
#create_operation_file, #validate_type!
Constructor Details
#initialize(*args) ⇒ ServiceGenerator
Returns a new instance of ServiceGenerator.
16 17 18 19 |
# File 'lib/generators/gaskit/operation/service_generator.rb', line 16 def initialize(*args) super [:type] = "service" end |